@@ -1,7 +1,8 @@
 use dotenv::dotenv;
+use ftx::options::Options;
 use ftx::ws::Result;
 use ftx::ws::{Channel, Data, Orderbook, Ws};
-use std::env::var;
+use futures::stream::StreamExt;
 use std::io;
 use std::io::Write;
 
@@ -9,12 +10,7 @@ use std::io::Write;
 async fn main() -> Result<()> {
     dotenv().ok();
 
-    let mut websocket = Ws::connect(
-        var("API_KEY").expect("API Key is not defined."),
-        var("API_SECRET").expect("API Secret is not defined."),
-        var("SUBACCOUNT").ok(),
-    )
-    .await?;
+    let mut websocket = Ws::connect(Options::from_env()).await?;
 
     let market = String::from("BTC-PERP");
     let mut orderbook = Orderbook::new(market.to_owned());
@@ -27,16 +23,16 @@ async fn main() -> Result<()> {
         .await?;
 
     loop {
-        let data = websocket.next().await?.expect("No data received");
+        let data = websocket.next().await.expect("No data received")?;
 
         match data {
-            Data::Trade(trade) => {
+            (_, Data::Trade(trade)) => {
                 println!(
                     "\n{:?} {} {} at {} - liquidation = {}",
                     trade.side, trade.size, market, trade.price, trade.liquidation
                 );
             }
-            Data::OrderbookData(orderbook_data) => {
+            (_, Data::OrderbookData(orderbook_data)) => {
                 orderbook.update(&orderbook_data);
                 print!("."); // To signify orderbook update
                 io::stdout().flush().unwrap(); // Emits the output immediately
