@@ -30,7 +30,7 @@ async fn get_subaccounts() {
     let rest = init_api().await;
     if rest.subaccount.is_none() {
         // Test only if credentials are account-wide
-        rest.request(GetSubaccounts).await.unwrap();
+        rest.request(GetSubaccounts {}).await.unwrap();
     }
 }
 
@@ -92,7 +92,7 @@ async fn transfer_between_subaccounts() {
 
 #[tokio::test]
 async fn get_markets() {
-    init_api().await.request(GetMarkets).await.unwrap();
+    init_api().await.request(GetMarkets {}).await.unwrap();
 }
 
 #[tokio::test]
@@ -142,7 +142,7 @@ async fn get_historical_prices() {
 
 #[tokio::test]
 async fn get_futures() {
-    init_api().await.request(GetFutures).await.unwrap();
+    init_api().await.request(GetFutures {}).await.unwrap();
 }
 
 #[tokio::test]
@@ -201,7 +201,25 @@ async fn account_deserialization() {
 
 #[tokio::test]
 async fn get_coins() {
-    init_api().await.request(GetCoins).await.unwrap();
+    init_api().await.request(GetCoins {}).await.unwrap();
+}
+
+#[tokio::test]
+async fn market_order() {
+    // A live test that buys 1 1INCH-PERP
+    /*
+    init_api().await.place_order(
+        "1INCH/USD",
+        Side::Buy,
+        None,
+        OrderType::Market,
+        dec!(1),
+        None,
+        None,
+        None,
+        None,
+    ).await.unwrap();
+    */
 }
 
 #[tokio::test]
@@ -305,3 +323,17 @@ pub async fn manipulate_orders() {
 
     assert_eq!(OrderStatus::New, rejected_order.status);
 }
+
+#[tokio::test]
+async fn get_open_orders() {
+    init_api()
+        .await
+        .request(GetOpenOrders::all_market())
+        .await
+        .unwrap();
+    init_api()
+        .await
+        .request(GetOpenOrders::with_market("ETH-PERP"))
+        .await
+        .unwrap();
+}
